@@ -1,5 +1,6 @@
 from unittest import TestCase, main
 from unittest.mock import patch, MagicMock
+
 from monolith_filemanager.file.vtk_file import VtkFile
 
 
@@ -12,13 +13,13 @@ class TestStlFile(TestCase):
 
     @patch("monolith_filemanager.file.vtk_file.expand_3d_point_arrays")
     @patch("monolith_filemanager.file.vtk_file.File.__init__")
-    @patch("monolith_filemanager.file.vtk_file.pv")
-    def test_read(self, mock_pv, mock_file, mock_expand_3d_point_arrays):
+    @patch("pyvista.read")
+    def test_read(self, mock_pv_read, mock_file, mock_expand_3d_point_arrays):
         mock_file.return_value = None
         test = VtkFile(path="test")
         test.path = "test"
         res = test.read()
-        mock_expand_3d_point_arrays.assert_called_once_with(mock_pv.read.return_value)
+        mock_expand_3d_point_arrays.assert_called_once_with(mock_pv_read.return_value)
         self.assertEqual(res, mock_expand_3d_point_arrays.return_value)
 
     @patch("monolith_filemanager.file.vtk_file.File.__init__")
